### Bycon - a Python-based environment for the Beacon genomics API

#### More Information

Additional information may be available through [info.progenetix.org](https://info.progenetix.org/doc/bycon/byconplus.html).

**NOTE** The Beacon v2 endpoints are _currently_ implemented under
`https://progenetix.org/beacon/...`. Documentation for Beacon v2 endpoints & use can be found through [[this link]](beacon_v2.md).
